@@ -460,7 +460,7 @@ def replace_flat_dict(key, value, relative_map, variables_dict, stack=None):
             for replace_item in relative_map[replaced_key]:
                 if replace_item == "${" + replaced_key + "}":
                     raise Exception("replaced_key {} can't be found!!".format(replaced_key))
-                elif replace_item.contains(replaced_key + ":"):
+                elif replaced_key + ":" in replace_item:
                     value = value.replace(replace_item, replace_item[2:-1].split(":")[-1])
         else:
             for replace_item in relative_map[replaced_key]:
